import React, { Fragment } from 'react'
import styled from 'styled-components'
import { th } from '@pubsweet/ui-toolkit'
import { Row, Text } from 'pubsweet-component-faraday-ui'
import { Checkbox, ValidatedField, H2, Action } from '@pubsweet/ui'

const StepOne = () => (
  <Fragment>
    <CustomH2>1. Pre-Submission Checklist</CustomH2>
    <Row mb={2}>
      <Text align="center" secondary>
        Before continuing please make sure you have all the required files
        prepared and have reviewed the items on the list below:
      </Text>
    </Row>
    <Row justify="flex-start" mb={1}>
      <Text>
        I am aware that accepted manuscripts are subject to an{' '}
        <Action>Article Processing Charge of $1,250.</Action>
      </Text>
    </Row>
    <Row justify="flex-start" mb={1}>
      <Text>
        All co-authors have read and agreed on the current version of this
        manuscript.
      </Text>
    </Row>
    <Row justify="flex-start" mb={1}>
      <Text>
        I have the email addresses of all co-authors of the manuscript.
      </Text>
    </Row>
    <Row justify="flex-start" mb={1}>
      <Text>
        I confirm the main manuscript file is in Microsoft Word or Adobe PDF
        format with the tables and figures integrated in the manuscript body.
      </Text>
    </Row>
    <Row justify="flex-start" mb={1}>
      <Text>
        I have all additional electronic files of supplementary materials (e.g.
        Datasets, images, audio, video) ready.
      </Text>
    </Row>
    <Row justify="flex-start" mb={1}>
      <Text>
        I am aware that an <Action>ORCID</Action> is required for the
        corresponding author before the article can be published (if accepted).
        The ORCID should be added via your user account.
      </Text>
    </Row>
    <Row justify="flex-start" mb={1}>
      <Text>
        I am aware that an <Action>institutional membership</Action> is required
        for the corresponding author before the article can be published (if
        accepted). The ORCID should be added via your user account.
      </Text>
    </Row>
    <Row justify="center" mb={6} mt={1}>
      <ValidatedField component={CustomCheckbox} name="declarations.agree" />
    </Row>
  </Fragment>
)

const CustomCheckbox = input => (
  <RootCheckbox data-test-id="agree-checkbox">
    <Checkbox
      checked={input.value}
      {...input}
      label={`I've reviewed and understood all the above items.`}
    />
  </RootCheckbox>
)

export default StepOne

// #region styled-components
const RootCheckbox = styled.div.attrs({
  className: 'custom-checkbox',
})`
  & label {
    margin-bottom: calc(${th('gridUnit')} / 2);
    & span {
      color: ${th('colorText')};
      font-family: ${th('fontReading')};
      font-size: ${th('fontSizeBase')};
    }
  }
`

const CustomH2 = H2.extend`
  margin: 0;
`
// #endregion
